pub struct ConfirmDialog {
pub title: String,
pub message: Option<String>,
pub variant: DialogVariant,
}Expand description
Confirmation dialog shown before executing an action.
Fields
title: Stringmessage: Option<String>variant: DialogVariantTrait Implementations
Sourceimpl Clone for ConfirmDialog
impl Clone for ConfirmDialog
Sourcefn clone(&self) -> ConfirmDialog
fn clone(&self) -> ConfirmDialog
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfirmDialog
impl Debug for ConfirmDialog
Sourceimpl<'de> Deserialize<'de> for ConfirmDialog
impl<'de> Deserialize<'de> for ConfirmDialog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfirmDialog
impl JsonSchema for ConfirmDialog
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfirmDialog
impl PartialEq for ConfirmDialog
Sourceimpl Serialize for ConfirmDialog
impl Serialize for ConfirmDialog
impl StructuralPartialEq for ConfirmDialog