pub struct AlertProps {
pub message: String,
pub variant: AlertVariant,
pub title: Option<String>,
}Expand description
Props for Alert component.
Fields
message: Stringvariant: AlertVarianttitle: Option<String>Trait Implementations
Sourceimpl Clone for AlertProps
impl Clone for AlertProps
Sourcefn clone(&self) -> AlertProps
fn clone(&self) -> AlertProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlertProps
impl Debug for AlertProps
Sourceimpl<'de> Deserialize<'de> for AlertProps
impl<'de> Deserialize<'de> for AlertProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AlertProps
impl JsonSchema for AlertProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AlertProps
impl PartialEq for AlertProps
Sourceimpl Serialize for AlertProps
impl Serialize for AlertProps
impl StructuralPartialEq for AlertProps