pub struct BadgeProps {
pub label: String,
pub variant: BadgeVariant,
}Expand description
Props for Badge component.
Fields
label: Stringvariant: BadgeVariantTrait Implementations
Sourceimpl Clone for BadgeProps
impl Clone for BadgeProps
Sourcefn clone(&self) -> BadgeProps
fn clone(&self) -> BadgeProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BadgeProps
impl Debug for BadgeProps
Sourceimpl<'de> Deserialize<'de> for BadgeProps
impl<'de> Deserialize<'de> for BadgeProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BadgeProps
impl JsonSchema for BadgeProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BadgeProps
impl PartialEq for BadgeProps
Sourceimpl Serialize for BadgeProps
impl Serialize for BadgeProps
impl Eq for BadgeProps
impl StructuralPartialEq for BadgeProps