pub struct BreadcrumbItem {
pub label: String,
pub url: Option<String>,
}Expand description
A single item in a breadcrumb trail.
Fields
label: Stringurl: Option<String>Trait Implementations
Sourceimpl Clone for BreadcrumbItem
impl Clone for BreadcrumbItem
Sourcefn clone(&self) -> BreadcrumbItem
fn clone(&self) -> BreadcrumbItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BreadcrumbItem
impl Debug for BreadcrumbItem
Sourceimpl<'de> Deserialize<'de> for BreadcrumbItem
impl<'de> Deserialize<'de> for BreadcrumbItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BreadcrumbItem
impl JsonSchema for BreadcrumbItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BreadcrumbItem
impl PartialEq for BreadcrumbItem
Sourcefn eq(&self, other: &BreadcrumbItem) -> bool
fn eq(&self, other: &BreadcrumbItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BreadcrumbItem
impl Serialize for BreadcrumbItem
impl Eq for BreadcrumbItem
impl StructuralPartialEq for BreadcrumbItem