pub struct BreadcrumbProps {
pub items: Vec<BreadcrumbItem>,
}Expand description
Props for Breadcrumb component.
Fields
items: Vec<BreadcrumbItem>Trait Implementations
Sourceimpl Clone for BreadcrumbProps
impl Clone for BreadcrumbProps
Sourcefn clone(&self) -> BreadcrumbProps
fn clone(&self) -> BreadcrumbProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BreadcrumbProps
impl Debug for BreadcrumbProps
Sourceimpl<'de> Deserialize<'de> for BreadcrumbProps
impl<'de> Deserialize<'de> for BreadcrumbProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BreadcrumbProps
impl JsonSchema for BreadcrumbProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BreadcrumbProps
impl PartialEq for BreadcrumbProps
Sourceimpl Serialize for BreadcrumbProps
impl Serialize for BreadcrumbProps
impl Eq for BreadcrumbProps
impl StructuralPartialEq for BreadcrumbProps