pub struct ButtonProps {
pub label: String,
pub variant: ButtonVariant,
pub size: Size,
pub disabled: Option<bool>,
pub icon: Option<String>,
pub icon_position: Option<IconPosition>,
pub button_type: Option<ButtonType>,
}Expand description
Props for Button component.
Fields
label: Stringvariant: ButtonVariantsize: Sizedisabled: Option<bool>icon: Option<String>icon_position: Option<IconPosition>Trait Implementations
Sourceimpl Clone for ButtonProps
impl Clone for ButtonProps
Sourcefn clone(&self) -> ButtonProps
fn clone(&self) -> ButtonProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ButtonProps
impl Debug for ButtonProps
Sourceimpl<'de> Deserialize<'de> for ButtonProps
impl<'de> Deserialize<'de> for ButtonProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ButtonProps
impl JsonSchema for ButtonProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ButtonProps
impl PartialEq for ButtonProps
Sourceimpl Serialize for ButtonProps
impl Serialize for ButtonProps
impl StructuralPartialEq for ButtonProps