pub struct CardProps {
pub title: String,
pub description: Option<String>,
pub subtitle: Option<String>,
pub badge: Option<String>,
pub max_width: Option<FormMaxWidth>,
pub footer: Vec<String>,
pub variant: CardVariant,
}Expand description
Props for Card component.
Fields
title: Stringdescription: Option<String>subtitle: Option<String>Optional muted secondary line rendered immediately below the title and
above the description. Pattern: name → role, customer → staff,
title → category. Visually text-sm text-text-muted.
badge: Option<String>Optional small badge text rendered alongside the title. Visually a Badge-styled pill inside the Card chrome — for status indicators, counters, countdown labels, etc. Independent of the title hierarchy.
max_width: Option<FormMaxWidth>IDs of footer elements (resolved against Spec.elements).
variant: CardVariantTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CardProps
impl<'de> Deserialize<'de> for CardProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CardProps
impl JsonSchema for CardProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CardProps