pub struct CheckboxProps {
pub field: String,
pub value: Option<String>,
pub label: String,
pub description: Option<String>,
pub checked: Option<bool>,
pub data_path: Option<String>,
pub required: Option<bool>,
pub disabled: Option<bool>,
pub error: Option<String>,
}Expand description
Props for Checkbox component.
Fields
field: StringForm field name for data binding.
value: Option<String>HTML value attribute. When set, the checkbox submits this value instead of “1”. Required for multi-value checkbox groups (same name, different values).
label: Stringdescription: Option<String>checked: Option<bool>data_path: Option<String>Data path for pre-filling from handler data (e.g., “/data/user/name”).
required: Option<bool>disabled: Option<bool>error: Option<String>Trait Implementations
Sourceimpl Clone for CheckboxProps
impl Clone for CheckboxProps
Sourcefn clone(&self) -> CheckboxProps
fn clone(&self) -> CheckboxProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckboxProps
impl Debug for CheckboxProps
Sourceimpl<'de> Deserialize<'de> for CheckboxProps
impl<'de> Deserialize<'de> for CheckboxProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CheckboxProps
impl JsonSchema for CheckboxProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CheckboxProps
impl PartialEq for CheckboxProps
Sourceimpl Serialize for CheckboxProps
impl Serialize for CheckboxProps
impl StructuralPartialEq for CheckboxProps