pub struct ChecklistItem {
pub label: String,
pub checked: bool,
pub href: Option<String>,
}Expand description
A single item in a checklist.
Fields
label: Stringchecked: boolhref: Option<String>Trait Implementations
Sourceimpl Clone for ChecklistItem
impl Clone for ChecklistItem
Sourcefn clone(&self) -> ChecklistItem
fn clone(&self) -> ChecklistItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChecklistItem
impl Debug for ChecklistItem
Sourceimpl<'de> Deserialize<'de> for ChecklistItem
impl<'de> Deserialize<'de> for ChecklistItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChecklistItem
impl JsonSchema for ChecklistItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChecklistItem
impl PartialEq for ChecklistItem
Sourceimpl Serialize for ChecklistItem
impl Serialize for ChecklistItem
impl Eq for ChecklistItem
impl StructuralPartialEq for ChecklistItem