pub struct CollapsibleProps {
pub title: String,
pub expanded: bool,
}Expand description
Props for Collapsible section — expandable <details>/<summary>.
Fields
title: Stringexpanded: boolTrait Implementations
Sourceimpl Clone for CollapsibleProps
impl Clone for CollapsibleProps
Sourcefn clone(&self) -> CollapsibleProps
fn clone(&self) -> CollapsibleProps
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollapsibleProps
impl Debug for CollapsibleProps
Sourceimpl<'de> Deserialize<'de> for CollapsibleProps
impl<'de> Deserialize<'de> for CollapsibleProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CollapsibleProps
impl JsonSchema for CollapsibleProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CollapsibleProps
impl PartialEq for CollapsibleProps
Sourcefn eq(&self, other: &CollapsibleProps) -> bool
fn eq(&self, other: &CollapsibleProps) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CollapsibleProps
impl Serialize for CollapsibleProps
impl StructuralPartialEq for CollapsibleProps