pub struct DescriptionItem {
pub label: String,
pub value: String,
pub format: Option<ColumnFormat>,
}Expand description
A single item in a description list.
Fields
label: Stringvalue: Stringformat: Option<ColumnFormat>Trait Implementations
Sourceimpl Clone for DescriptionItem
impl Clone for DescriptionItem
Sourcefn clone(&self) -> DescriptionItem
fn clone(&self) -> DescriptionItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DescriptionItem
impl Debug for DescriptionItem
Sourceimpl<'de> Deserialize<'de> for DescriptionItem
impl<'de> Deserialize<'de> for DescriptionItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DescriptionItem
impl JsonSchema for DescriptionItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DescriptionItem
impl PartialEq for DescriptionItem
Sourceimpl Serialize for DescriptionItem
impl Serialize for DescriptionItem
impl Eq for DescriptionItem
impl StructuralPartialEq for DescriptionItem