pub struct DescriptionListProps {
pub items: Vec<DescriptionItem>,
pub columns: Option<u8>,
}Expand description
Props for DescriptionList component.
Fields
items: Vec<DescriptionItem>columns: Option<u8>Trait Implementations
Sourceimpl Clone for DescriptionListProps
impl Clone for DescriptionListProps
Sourcefn clone(&self) -> DescriptionListProps
fn clone(&self) -> DescriptionListProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DescriptionListProps
impl Debug for DescriptionListProps
Sourceimpl<'de> Deserialize<'de> for DescriptionListProps
impl<'de> Deserialize<'de> for DescriptionListProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DescriptionListProps
impl JsonSchema for DescriptionListProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DescriptionListProps
impl PartialEq for DescriptionListProps
Sourceimpl Serialize for DescriptionListProps
impl Serialize for DescriptionListProps
impl Eq for DescriptionListProps
impl StructuralPartialEq for DescriptionListProps