pub struct EmptyStateProps {
pub title: String,
pub description: Option<String>,
pub action: Option<Action>,
pub action_label: Option<String>,
}Expand description
Props for EmptyState component — standardized empty view.
Fields
title: Stringdescription: Option<String>action: Option<Action>action_label: Option<String>Trait Implementations
Sourceimpl Clone for EmptyStateProps
impl Clone for EmptyStateProps
Sourcefn clone(&self) -> EmptyStateProps
fn clone(&self) -> EmptyStateProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmptyStateProps
impl Debug for EmptyStateProps
Sourceimpl<'de> Deserialize<'de> for EmptyStateProps
impl<'de> Deserialize<'de> for EmptyStateProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmptyStateProps
impl JsonSchema for EmptyStateProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EmptyStateProps
impl PartialEq for EmptyStateProps
Sourceimpl Serialize for EmptyStateProps
impl Serialize for EmptyStateProps
impl StructuralPartialEq for EmptyStateProps