pub struct HeaderProps {
pub business_name: String,
pub notification_count: Option<u32>,
pub user_name: Option<String>,
pub user_avatar: Option<String>,
pub logout_url: Option<String>,
}Expand description
Props for Header component.
Fields
business_name: Stringnotification_count: Option<u32>Unread notification count for badge display.
user_name: Option<String>user_avatar: Option<String>logout_url: Option<String>Trait Implementations
Sourceimpl Clone for HeaderProps
impl Clone for HeaderProps
Sourcefn clone(&self) -> HeaderProps
fn clone(&self) -> HeaderProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeaderProps
impl Debug for HeaderProps
Sourceimpl<'de> Deserialize<'de> for HeaderProps
impl<'de> Deserialize<'de> for HeaderProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HeaderProps
impl JsonSchema for HeaderProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HeaderProps
impl PartialEq for HeaderProps
Sourceimpl Serialize for HeaderProps
impl Serialize for HeaderProps
impl Eq for HeaderProps
impl StructuralPartialEq for HeaderProps