pub struct NotificationDropdownProps {
pub notifications: Vec<NotificationItem>,
pub empty_text: Option<String>,
}Expand description
Props for NotificationDropdown component.
Fields
notifications: Vec<NotificationItem>empty_text: Option<String>Trait Implementations
Sourceimpl Clone for NotificationDropdownProps
impl Clone for NotificationDropdownProps
Sourcefn clone(&self) -> NotificationDropdownProps
fn clone(&self) -> NotificationDropdownProps
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationDropdownProps
impl Debug for NotificationDropdownProps
Sourceimpl<'de> Deserialize<'de> for NotificationDropdownProps
impl<'de> Deserialize<'de> for NotificationDropdownProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NotificationDropdownProps
Sourceimpl JsonSchema for NotificationDropdownProps
impl JsonSchema for NotificationDropdownProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NotificationDropdownProps
impl PartialEq for NotificationDropdownProps
Sourcefn eq(&self, other: &NotificationDropdownProps) -> bool
fn eq(&self, other: &NotificationDropdownProps) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NotificationDropdownProps