pub struct NotificationItem {
pub icon: Option<String>,
pub text: String,
pub timestamp: Option<String>,
pub read: bool,
pub action_url: Option<String>,
}Expand description
A single item in a notification dropdown.
Fields
icon: Option<String>text: Stringtimestamp: Option<String>read: boolaction_url: Option<String>Trait Implementations
Sourceimpl Clone for NotificationItem
impl Clone for NotificationItem
Sourcefn clone(&self) -> NotificationItem
fn clone(&self) -> NotificationItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationItem
impl Debug for NotificationItem
Sourceimpl<'de> Deserialize<'de> for NotificationItem
impl<'de> Deserialize<'de> for NotificationItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationItem
impl JsonSchema for NotificationItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NotificationItem
impl PartialEq for NotificationItem
Sourceimpl Serialize for NotificationItem
impl Serialize for NotificationItem
impl Eq for NotificationItem
impl StructuralPartialEq for NotificationItem