pub struct PaginationProps {
pub current_page: u32,
pub per_page: u32,
pub total: u32,
pub base_url: Option<String>,
}Expand description
Props for Pagination component.
Fields
current_page: u32per_page: u32total: u32base_url: Option<String>Trait Implementations
Sourceimpl Clone for PaginationProps
impl Clone for PaginationProps
Sourcefn clone(&self) -> PaginationProps
fn clone(&self) -> PaginationProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaginationProps
impl Debug for PaginationProps
Sourceimpl<'de> Deserialize<'de> for PaginationProps
impl<'de> Deserialize<'de> for PaginationProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PaginationProps
impl JsonSchema for PaginationProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PaginationProps
impl PartialEq for PaginationProps
Sourceimpl Serialize for PaginationProps
impl Serialize for PaginationProps
impl Eq for PaginationProps
impl StructuralPartialEq for PaginationProps