pub struct ProgressProps {
pub value: u8,
pub max: Option<u8>,
pub label: Option<String>,
}Expand description
Props for Progress component.
Fields
value: u8Percentage value (0-100).
max: Option<u8>label: Option<String>Trait Implementations
Sourceimpl Clone for ProgressProps
impl Clone for ProgressProps
Sourcefn clone(&self) -> ProgressProps
fn clone(&self) -> ProgressProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressProps
impl Debug for ProgressProps
Sourceimpl<'de> Deserialize<'de> for ProgressProps
impl<'de> Deserialize<'de> for ProgressProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressProps
impl JsonSchema for ProgressProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressProps
impl PartialEq for ProgressProps
Sourceimpl Serialize for ProgressProps
impl Serialize for ProgressProps
impl Eq for ProgressProps
impl StructuralPartialEq for ProgressProps