pub struct SeparatorProps {
pub orientation: Option<Orientation>,
}Expand description
Props for Separator component.
Fields
orientation: Option<Orientation>Trait Implementations
Sourceimpl Clone for SeparatorProps
impl Clone for SeparatorProps
Sourcefn clone(&self) -> SeparatorProps
fn clone(&self) -> SeparatorProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SeparatorProps
impl Debug for SeparatorProps
Sourceimpl<'de> Deserialize<'de> for SeparatorProps
impl<'de> Deserialize<'de> for SeparatorProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SeparatorProps
impl JsonSchema for SeparatorProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SeparatorProps
impl PartialEq for SeparatorProps
Sourceimpl Serialize for SeparatorProps
impl Serialize for SeparatorProps
impl Eq for SeparatorProps
impl StructuralPartialEq for SeparatorProps