pub struct SidebarGroup {
pub label: String,
pub collapsed: bool,
pub items: Vec<SidebarNavItem>,
}Expand description
A collapsible group in the sidebar.
Fields
label: Stringcollapsed: boolitems: Vec<SidebarNavItem>Trait Implementations
Sourceimpl Clone for SidebarGroup
impl Clone for SidebarGroup
Sourcefn clone(&self) -> SidebarGroup
fn clone(&self) -> SidebarGroup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SidebarGroup
impl Debug for SidebarGroup
Sourceimpl<'de> Deserialize<'de> for SidebarGroup
impl<'de> Deserialize<'de> for SidebarGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SidebarGroup
impl JsonSchema for SidebarGroup
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SidebarGroup
impl PartialEq for SidebarGroup
Sourceimpl Serialize for SidebarGroup
impl Serialize for SidebarGroup
impl Eq for SidebarGroup
impl StructuralPartialEq for SidebarGroup