pub struct SkeletonProps {
pub width: Option<String>,
pub height: Option<String>,
pub rounded: Option<bool>,
}Expand description
Props for Skeleton loading placeholder.
Fields
width: Option<String>height: Option<String>rounded: Option<bool>Trait Implementations
Sourceimpl Clone for SkeletonProps
impl Clone for SkeletonProps
Sourcefn clone(&self) -> SkeletonProps
fn clone(&self) -> SkeletonProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkeletonProps
impl Debug for SkeletonProps
Sourceimpl<'de> Deserialize<'de> for SkeletonProps
impl<'de> Deserialize<'de> for SkeletonProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SkeletonProps
impl JsonSchema for SkeletonProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SkeletonProps
impl PartialEq for SkeletonProps
Sourceimpl Serialize for SkeletonProps
impl Serialize for SkeletonProps
impl Eq for SkeletonProps
impl StructuralPartialEq for SkeletonProps