pub struct TableProps {
pub columns: Vec<Column>,
pub data_path: String,
pub row_actions: Option<Vec<Action>>,
pub empty_message: Option<String>,
pub sortable: Option<bool>,
pub sort_column: Option<String>,
pub sort_direction: Option<SortDirection>,
}Expand description
Props for Table component.
Fields
columns: Vec<Column>data_path: Stringrow_actions: Option<Vec<Action>>empty_message: Option<String>sortable: Option<bool>sort_column: Option<String>sort_direction: Option<SortDirection>Trait Implementations
Sourceimpl Clone for TableProps
impl Clone for TableProps
Sourcefn clone(&self) -> TableProps
fn clone(&self) -> TableProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableProps
impl Debug for TableProps
Sourceimpl<'de> Deserialize<'de> for TableProps
impl<'de> Deserialize<'de> for TableProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TableProps
impl JsonSchema for TableProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TableProps
impl PartialEq for TableProps
Sourceimpl Serialize for TableProps
impl Serialize for TableProps
impl StructuralPartialEq for TableProps