pub struct DataRef {
pub data: String,
}Expand description
{"$data": "/path"} shape — references a JSON pointer in spec.data.
Mirrors the $data key recognised by expression resolution
(see expression.rs:EXPR_DATA_KEY).
Fields
data: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for DataRef
impl<'de> Deserialize<'de> for DataRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DataRef
impl JsonSchema for DataRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DataRef