pub struct AvatarProps {
pub src: Option<String>,
pub alt: String,
pub fallback: Option<String>,
pub size: Option<Size>,
}Expand description
Props for Avatar component.
Fields
src: Option<String>alt: Stringfallback: Option<String>size: Option<Size>Trait Implementations
Sourceimpl Clone for AvatarProps
impl Clone for AvatarProps
Sourcefn clone(&self) -> AvatarProps
fn clone(&self) -> AvatarProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AvatarProps
impl Debug for AvatarProps
Sourceimpl<'de> Deserialize<'de> for AvatarProps
impl<'de> Deserialize<'de> for AvatarProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AvatarProps
impl JsonSchema for AvatarProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AvatarProps
impl PartialEq for AvatarProps
Sourceimpl Serialize for AvatarProps
impl Serialize for AvatarProps
impl Eq for AvatarProps
impl StructuralPartialEq for AvatarProps