pub struct SelectOption {
pub value: String,
pub label: String,
}Expand description
Select option (value + label pair).
Fields
value: Stringlabel: StringTrait Implementations
Sourceimpl Clone for SelectOption
impl Clone for SelectOption
Sourcefn clone(&self) -> SelectOption
fn clone(&self) -> SelectOption
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectOption
impl Debug for SelectOption
Sourceimpl<'de> Deserialize<'de> for SelectOption
impl<'de> Deserialize<'de> for SelectOption
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SelectOption
impl JsonSchema for SelectOption
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SelectOption
impl PartialEq for SelectOption
Sourceimpl Serialize for SelectOption
impl Serialize for SelectOption
impl Eq for SelectOption
impl StructuralPartialEq for SelectOption