pub struct SidebarProps {
pub fixed_top: Vec<SidebarNavItem>,
pub groups: Vec<SidebarGroup>,
pub fixed_bottom: Vec<SidebarNavItem>,
}Expand description
Props for Sidebar component.
Fields
fixed_top: Vec<SidebarNavItem>groups: Vec<SidebarGroup>fixed_bottom: Vec<SidebarNavItem>Trait Implementations
Sourceimpl Clone for SidebarProps
impl Clone for SidebarProps
Sourcefn clone(&self) -> SidebarProps
fn clone(&self) -> SidebarProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SidebarProps
impl Debug for SidebarProps
Sourceimpl<'de> Deserialize<'de> for SidebarProps
impl<'de> Deserialize<'de> for SidebarProps
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SidebarProps
impl JsonSchema for SidebarProps
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SidebarProps
impl PartialEq for SidebarProps
Sourceimpl Serialize for SidebarProps
impl Serialize for SidebarProps
impl Eq for SidebarProps
impl StructuralPartialEq for SidebarProps