Module resolve

Module resolve 

Resolvers for JSON-UI component trees.

Walks a JsonUiView’s component tree and resolves action handler references to URLs and validation errors to form field error messages. Both resolvers keep ferro-json-ui decoupled from the framework.

Functions

resolve_actions
Walk the entire component tree and resolve all action handler names to URLs.
resolve_actions_strict
Walk the entire component tree and resolve all actions, returning an error for any handler that cannot be resolved.
resolve_errors
Walk the component tree and set the first validation error message on each matching form field component (Input, Select, Checkbox, Switch).
resolve_errors_all
Walk the component tree and set all validation error messages (joined with ". ") on each matching form field component.